Struct tide_disco::api::ApiMetadata

source ·
pub struct ApiMetadata {
Show 14 fields pub name: String, pub description: String, pub format_version: Version, pub html_top: String, pub html_bottom: String, pub heading_entry: String, pub heading_routes: String, pub heading_parameters: String, pub heading_description: String, pub route_path: String, pub parameter_table_open: String, pub parameter_table_close: String, pub parameter_row: String, pub parameter_none: String,
}
Metadata used for describing and documenting an API.

ApiMetadata contains version information about the API, as well as optional HTML fragments to customize the formatting of automatically generated API documentation. Each of the supported HTML fragments is optional and will be filled in with a reasonable default if not provided. Some of the HTML fragments may contain “placeholders”, which are identifiers enclosed in {{ }}, like {{SOME_PLACEHOLDER}}. These will be replaced by contextual information when the documentation is generated. The placeholders supported by each HTML fragment are documented below.

Fields

name: String

The name of this API.

Note that the name of the API may be overridden if the API is registered with an app using a different name.

description: String

A description of this API.

format_version: Version

The version of the Tide Disco API specification format.

If not specified, the version of this crate will be used.

html_top: String

HTML to be prepended to automatically generated documentation.

Placeholders

  • NAME: the name of the API
  • DESCRIPTION: the description provided in Cargo.toml
  • VERSION: the version of the API
  • FORMAT_VERSION: the FORMAT_VERSION of the API
  • PUBLIC: the URL where the public directory for this API is being served
html_bottom: String

HTML to be appended to automatically generated documentation.

heading_entry: String

The heading for documentation of a route.

Placeholders

  • METHOD: the method of the route
  • NAME: the name of the route
heading_routes: String

The heading preceding documentation of all routes in this API.

heading_parameters: String

The heading preceding documentation of route parameters.

heading_description: String

The heading preceding documentation of a route description.

route_path: String

HTML formatting the path of a route.

Placeholders

  • PATH: the path being formatted
parameter_table_open: String

HTML preceding the contents of a table documenting the parameters of a route.

parameter_table_close: String

HTML closing a table documenting the parameters of a route.

parameter_row: String

HTML formatting an entry in a table documenting the parameters of a route.

Placeholders

  • NAME: the parameter being documented
  • TYPE: the type of the parameter being documented
parameter_none: String

Documentation to insert in the parameters section of a route with no parameters.