Struct tide_disco::app::AppVersion
source · pub struct AppVersion {
pub modules: BTreeMap<String, Vec<ApiVersion>>,
pub app_version: Option<Version>,
pub disco_version: Version,
}Expand description
Version information about an application.
Fields
modules: BTreeMap<String, Vec<ApiVersion>>The supported versions of each module registered with this application.
Versions for each module are ordered from newest to oldest.
app_version: Option<Version>The version of this application.
disco_version: VersionThe version of the Tide Disco server framework.